diff --git a/src/Ombi/Controllers/V1/JobController.cs b/src/Ombi/Controllers/V1/JobController.cs
index 7f05474dc..b8ae1446b 100644
--- a/src/Ombi/Controllers/V1/JobController.cs
+++ b/src/Ombi/Controllers/V1/JobController.cs
@@ -93,10 +93,21 @@ namespace Ombi.Controllers.V1
}
///
/// Runs the Jellyfin User importer
///
///
[HttpPost("embyuserimporter")]
+ public async Task EmbyUserImporter()
+ {
+ await OmbiQuartz.TriggerJob(nameof(IEmbyUserImporter), "Emby");
+ return true;
+ }
+
+ ///
+ /// Runs the Jellyfin User importer
+ ///
+ ///
+ [HttpPost("jellyfinuserimporter")]
public async Task JellyfinUserImporter()
{
await OmbiQuartz.TriggerJob(nameof(IJellyfinUserImporter), "Jellyfin");
@@ -93,10 +93,21 @@ namespace Ombi.Controllers.V1
}
///
- /// Runs the Jellyfin User importer
+ /// Runs the Emby User importer
///
///